<?php
$translations = array(
	'General_Locale' => 'ca_ES.UTF-8',
	'General_TranslatorName' => 'Isaac Sánchez Barrera, Joan Juvanteny',
	'General_TranslatorEmail' => 'isb1009 [at] [don\'t write this] astronomipedia [dot] es,jjuvan@grn.cat',
	'General_EnglishLanguageName' => 'Catalan',
	'General_OriginalLanguageName' => 'Català',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Hola, %s!',
	'General_OpenSourceWebAnalytics' => 'Anàlisi web de codi obert',
	'General_Dashboard' => 'Tauler',
	'General_DashboardForASpecificWebsite' => 'Tauler per un lloc web concret',
	'General_MultiSitesSummary' => 'Tots els llocs web',
	'General_AllWebsitesDashboard' => 'Tauler de tots els llocs web',
	'General_API' => 'API',
	'General_Widgets' => 'Ginys',
	'General_Settings' => 'Tauler de control',
	'General_GiveUsYourFeedback' => 'Què penseu del Piwik?',
	'General_Unknown' => 'Desconegut',
	'General_Never' => 'Mai',
	'General_Required' => '%s requerit',
	'General_NotValid' => '%s no és vàlid',
	'General_NotDefined' => '%s no definit',
	'General_Id' => 'Id',
	'General_Error' => 'Error',
	'General_Warning' => 'Avís',
	'General_BackToHomepage' => 'Torna a la pàgina principal de Piwik',
	'General_Yes' => 'Sí',
	'General_No' => 'No',
	'General_Delete' => 'Esborra',
	'General_Report' => 'Informe',
	'General_Reports' => 'Informes',
	'General_Edit' => 'Edita',
	'General_Download' => 'Descàrrega',
	'General_Upload' => 'Càrrega',
	'General_Ok' => 'D\'acord',
	'General_Close' => 'Tanca',
	'General_OrCancel' => 'o %s cancel·la %s',
	'General_Logout' => 'Surt',
	'General_Username' => 'Usuari',
	'General_Description' => 'Descripció',
	'General_Done' => 'Fet',
	'General_PoweredBy' => 'Funcionant amb',
	'General_MetricsToPlot' => 'Valors per graficar',
	'General_RowsToDisplay' => 'Files a mostrar',
	'General_MetricToPlot' => 'Mètrica a mostrar',
	'General_RecordsToPlot' => 'Entrades a mostrar',
	'General_Name' => 'Nom',
	'General_Value' => 'Valor',
	'General_Total' => 'Total',
	'General_TotalVisitsActionsRevenue' => '(Total: %s visite, %s accions, %s ingressos)',
	'General_AverageOrderValue' => 'Valor mig de les comandes',
	'General_PurchasedProducts' => 'Productes comprats',
	'General_EcommerceOrders' => 'Comandes d\'e-commerce',
	'General_AbandonedCarts' => 'Cistelles abandonades',
	'General_TotalRevenue' => 'Total Ingressos',
	'General_ProductRevenue' => 'Ingressos de productes',
	'General_AveragePrice' => 'Preu mig',
	'General_AverageQuantity' => 'Qualitat mitja',
	'General_UniquePurchases' => 'Compres úniques',
	'General_ProductConversionRate' => 'Taxa de conversió del producte',
	'General_Quantity' => 'Quantitat',
	'General_Price' => 'Preu',
	'General_Subtotal' => 'Subtotal',
	'General_Tax' => 'Impostos',
	'General_Shipping' => 'Enviament',
	'General_Discount' => 'Descompte',
	'General_Details' => 'Detalls',
	'General_Default' => 'Per defecte',
	'General_Visit' => 'Visita',
	'General_FromReferrer' => 'de',
	'General_VisitorIP' => 'Ip del visitant',
	'General_VisitorID' => 'ID del visitant',
	'General_VisitType' => 'Tipus de visitant',
	'General_VisitTypeExample' => 'Per exemple, per seleccionar tots els visitants que han retornat al lloc web, incloent els que han comprat alguna cosa en anteriors visites, la petició de l\'API tindria %s',
	'General_DaysSinceLastVisit' => 'Dies des de l\'última visita',
	'General_DaysSinceFirstVisit' => 'Dies des de la primera visita',
	'General_DaysSinceLastEcommerceOrder' => 'Dies des de la última comanda d\'e-commerce',
	'General_NumberOfVisits' => 'Número de visites',
	'General_VisitConvertedGoal' => 'La visita ha convertit al menys un objectiu',
	'General_VisitConvertedGoalId' => 'La visita ha convertit un id d\'objectiu especific',
	'General_EcommerceVisitStatus' => 'Visita l\'estat de l\'e-commerce al final de la visita. Per exempel, seleccionar totes les visites que han fet una comanda d\'e-commerce, la petició de l\'API tindrà %s',
	'General_VisitConvertedNGoals' => 'La visita ha convertit %s objectius',
	'General_NewVisitor' => 'Nova visita',
	'General_NewVisits' => 'Noves visites',
	'General_ReturningVisitor' => 'Visita que retorna',
	'General_Visitor' => 'Visita',
	'General_Date' => 'Data',
	'General_Period' => 'Període',
	'General_ChooseDate' => 'Triar data',
	'General_Today' => 'Avui',
	'General_Yesterday' => 'Ahir',
	'General_CurrentWeek' => 'Setmana actual',
	'General_CurrentMonth' => 'Mes actual',
	'General_CurrentYear' => 'Any actual',
	'General_DateRange' => 'Rang de dates:',
	'General_DateRangeInPeriodList' => 'Rang de dates',
	'General_DateRangeFromTo' => 'De %s fins a %s',
	'General_ApplyDateRange' => 'Aplicar un rang de dates',
	'General_InvalidDateRange_js' => 'Rang de dates no vàlid, si us plau proveu-ho de nou',
	'General_DateRangeFrom_js' => 'De',
	'General_DateRangeTo_js' => 'Fins',
	'General_PreviousDays' => '%s dies anteriors (sense incloure avui)',
	'General_LastDays' => 'Últims %s dies (incloent avui)',
	'General_LoadingData' => 'Les dades s\'estan carregant…',
	'General_Loading_js' => 'Carregant…',
	'General_GoTo' => 'Anar a %s',
	'General_Next' => 'Següent',
	'General_Previous' => 'Anterior',
	'General_First' => 'Primer',
	'General_Search' => 'Cerca',
	'General_Others' => 'Altres',
	'General_Table' => 'Taula',
	'General_Piechart' => 'Gràfic de sectors',
	'General_TagCloud' => 'Núvol d\'etiquetes',
	'General_VBarGraph' => 'Gràfic de barres',
	'General_View' => 'Vista',
	'General_OpenInNewWindow_js' => 'Obrir en una nova finestra',
	'General_SaveImageOnYourComputer_js' => 'Per guardar la imatge al vostre ordinador, feu click amb el botó dret sobre la imatge i trieu "Guardar la imatge com.."',
	'General_Refresh' => 'Actualitza la pàgina',
	'General_Visitors' => 'Visitants',
	'General_ExportThisReport' => 'Guardar aquestes dades en altres formats',
	'General_ExportAsImage_js' => 'Exportar com a imatge',
	'General_Export' => 'Exporta',
	'General_ParameterMustIntegerBetween' => 'El paràmetre %s ha de ser un enter entre %s i %s',
	'General_YourChangesHaveBeenSaved' => 'Els vostres canvis s\'han guardat',
	'General_ErrorRequest' => 'Ups! Hi ha hagut un problema amb la sol·licitud, torneu-ho a intentar.',
	'General_ColumnNbUniqVisitors' => 'Visitants únics',
	'General_ColumnNbUniqVisitorsDocumentation' => 'El número de visitant únics que han vingut al vostre lloc web. Cada usuari es compta només una vegada, encara que visiti el lloc web més d\'un cop al dia.',
	'General_ColumnNbVisits' => 'Visites',
	'General_ColumnNbVisitsDocumentation' => 'Si la visita arriba al vostre lloc web per primera vegada o si obre una pàgina després de més de 30 minuts sense activitat, es comptarà com una nova visita.',
	'General_ColumnPercentageVisits' => '% Visites',
	'General_ColumnNbActions' => 'Accions',
	'General_ColumnNbActionsDocumentation' => 'El número d\'accions que han realitzat els vostres visitant. Les accions poden ser pàgines vistes, descarregues o enllaços externs.',
	'General_NbActions' => 'Número d\'accions',
	'General_ColumnMaxActions' => 'Accions màximes en una visita',
	'General_ColumnSumVisitLength' => 'Temps total acumulat pels visitants (en segons)',
	'General_ColumnLabel' => 'Etiqueta',
	'General_ColumnConversionRate' => 'Tarifa de conversió',
	'General_ColumnConversionRateDocumentation' => 'El percentatge de visites que han disparat una conversió d\'objectiu.',
	'General_ColumnActionsPerVisit' => 'Accions per visita',
	'General_ColumnActionsPerVisitDocumentation' => 'El número mig d\'accions (pàgines vistes, descarregues o enllaços de sortida) que s\'han fet durant les visites.',
	'General_VisitDuration' => 'Temps mig de visita (en segons)',
	'General_ColumnAvgTimeOnSite' => 'Temps mitjà per visita',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'La durada mitja de una visita.',
	'General_ColumnVisitDuration' => 'Durada de la visita (en segons)',
	'General_ColumnBounceRate' => 'Raó de rebots',
	'General_ColumnBounceRateDocumentation' => 'El percentatge de visites que només han vist una pàgina. Això significa, que el visitant ha marxat del lloc web directament per la pàgina d\'entrada.',
	'General_ColumnBounceRateForPageDocumentation' => 'El percentatge de visites que han acabat en aquesta pàgina.',
	'General_ColumnPageBounceRateDocumentation' => 'El percentatge de visites que han començat en aquesta pàgina i han deixat el lloc web directament.',
	'General_ColumnExitRate' => 'Taxa de sortida',
	'General_ColumnExitRateDocumentation' => 'El percentatge de visites que han deixat el lloc web després de veure aquesta pàgina.',
	'General_ColumnPageviews' => 'Visualitzacions de pàgina',
	'General_ColumnPageviewsDocumentation' => 'El número de vegades que s\'ha visitat aquesta pàgina.',
	'General_ColumnUniquePageviews' => 'Visualitzacions de pàgina úniques',
	'General_ColumnUniquePageviewsDocumentation' => 'El número de visites que incloïen aquesta pàgina. Si una pàgina s\'ha vist múltiples vegades durant una visita, només es compta un cop.',
	'General_ColumnBounces' => 'Rebots',
	'General_ColumnBouncesDocumentation' => 'El número de visites que han començat i acabat en aquesta pàgina. Això significa que la visita ha deixat el lloc web després de veure només aquesta pàgina.',
	'General_ColumnUniqueEntrances' => 'Entrades úniques',
	'General_ColumnEntrances' => 'Entrades',
	'General_ColumnEntrancesDocumentation' => 'Número de visites que han començat en aquesta pàgina.',
	'General_ColumnExits' => 'Sortides',
	'General_ColumnUniqueExits' => 'Sortides úniques',
	'General_ColumnExitsDocumentation' => 'Número de visites que acaben en aquesta pàgina.',
	'General_ColumnAverageTimeOnPage' => 'Temps mig a la pàgina',
	'General_ColumnAverageTimeOnPageDocumentation' => 'La mitjana de temps que els visitants s\'han passat en aquesta pàgina (només la pàgina no el lloc enter).',
	'General_ColumnValuePerVisit' => 'Valor per visita',
	'General_ColumnVisitsWithConversions' => 'Visites amb conversions',
	'General_VisitsWith' => 'Visites amb %s',
	'General_HoursMinutes' => '%1$s hores %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Desa',
	'General_Faq' => 'PMF',
	'General_ForExampleShort' => 'p.ex.',
	'General_YouMustBeLoggedIn' => 'Has d\'entrar per accedir a aquesta funcionalitat.',
	'General_Website' => 'Lloc web',
	'General_GeneralSettings' => 'Paràmetres generals',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Permetre que l\'arxivat del Piwik es dispari quan els informes es veuen des del navegador',
	'General_ArchivingInlineHelp' => 'Per llocs amb transit entre mig i alt, es recomana desactivar l\'arxivat del Piwik des del navegador. En canvi, recomanem que configureu una tasca de cron per processar els informes de Piwik cada hora.',
	'General_ArchivingTriggerDescription' => 'Recomanat per instal·lacions grans de Piwik, es pot %sconfigurar una %stasca programada per processar les entrades automàticament.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Vegeu la %sinformació oficial%s per més informació.',
	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Informes per avui (o un altre rang de dates incloent avui) es processaran com a molt cada',
	'General_NSeconds' => '%s segons',
	'General_SmallTrafficYouCanLeaveDefault' => 'Per llocs amb poc transit, pots deixar el valor per defecte de %s segons i accedir als informes en temps real.',
	'General_RequiresFlash' => 'Mostrar gràfics en el Piwik requereix Flash',
	'General_NoDataForGraph' => 'No hi ha dades...',
	'General_NoDataForTagCloud' => 'No hi ha dades...',
	'General_DisplaySimpleTable' => 'Mostrar una taula simple',
	'General_DisplayTableWithMoreMetrics' => 'Mostrar una taula amb més paràmetres',
	'General_DisplayTableWithGoalMetrics' => 'Mostrar una taula amb paràmetres globals',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => 'El %1$s Piwik %2$s és un projecte col·laboratiu. %3$s Si us agrada, podeu ajudar-nos! Mireu-vos %4$s Com col·laborar amb el Piwik (en anglès)%5$s',
	'General_YouAreViewingDemoShortMessage' => 'Ara mateix estàs veient la demo del Piwik',
	'General_YouAreCurrentlyUsing' => 'Ara mateix estàs fent servir el Piwik %s.',
	'General_NewUpdatePiwikX' => 'Nova actualització: Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Hi ha una nova versió del Piwik, %1$s, disponible! %2$s Si us plau, actualitzeu ara!%3$s (%4$s Mostra els canvis%5$s)',
	'General_BackToPiwik' => 'Torna al Piwik',
	'General_ClickHere' => 'Fes clic aquí per més informació.',
	'General_ShortMonth_1' => 'Gen',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Abr',
	'General_ShortMonth_5' => 'Mar',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Ago',
	'General_ShortMonth_9' => 'Set',
	'General_ShortMonth_10' => 'Oct',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Des',
	'General_LongMonth_1' => 'gener',
	'General_LongMonth_2' => 'febrer',
	'General_LongMonth_3' => 'març',
	'General_LongMonth_4' => 'abril',
	'General_LongMonth_5' => 'maig',
	'General_LongMonth_6' => 'juny',
	'General_LongMonth_7' => 'juliol',
	'General_LongMonth_8' => 'agost',
	'General_LongMonth_9' => 'setembre',
	'General_LongMonth_10' => 'octubre',
	'General_LongMonth_11' => 'novembre',
	'General_LongMonth_12' => 'desembre',
	'General_ShortDay_1' => 'dl',
	'General_ShortDay_2' => 'dt',
	'General_ShortDay_3' => 'dc',
	'General_ShortDay_4' => 'dj',
	'General_ShortDay_5' => 'dv',
	'General_ShortDay_6' => 'ds',
	'General_ShortDay_7' => 'dg',
	'General_LongDay_1' => 'dilluns',
	'General_LongDay_2' => 'dimarts',
	'General_LongDay_3' => 'dimecres',
	'General_LongDay_4' => 'dijous',
	'General_LongDay_5' => 'divendres',
	'General_LongDay_6' => 'dissabte',
	'General_LongDay_7' => 'diumenge',
	'General_Daily' => 'Diariament',
	'General_Weekly' => 'Setmanalment',
	'General_Monthly' => 'Mensualment',
	'General_ConfigFileIsNotWritable' => 'El fitxer de configuració del Piwiki %s no es pot modificar, alguns dels canvis que has fet no es guardaran. Si us plau %s canvia els permisos del fitxer de configuració per tal que es pugui modificar.',
	'General_ExceptionDatabaseVersion' => 'La teva %1$s versió és %s2$s però el Piwik necessita com a mínim %3$s',
	'General_ExceptionMissingFile' => 'Falta fitxer: %s',
	'General_ExceptionFileIntegrity' => 'Ha fallat la verificació de integritat: %s',
	'General_ExceptionNonceMismatch' => 'No s\'ha pogut verificar el token del formulari.',
	'General_ExceptionGoalNotFound' => 'L\'objectiu amb id = %s no s\'ha trobat.',
	'General_ExceptionUndeletableFile' => 'No s\'ha pogut esborrar %s',
	'General_ExceptionPrivilege' => 'No podeu accedir a aquest recurs perquè requereix un accés de %s',
	'General_ExceptionLanguageFileNotFound' => 'El fitxer d\'idioma \'%s\' no s\'ha trobat.',
	'General_ExceptionUnableToStartSession' => 'No s\'ha pogut començar la sessió.',
	'General_UseSMTPServerForEmail' => 'Fer servir un servidor SMTP per el correu',
	'General_SmtpServerAddress' => 'adreça del servidor SMTP',
	'General_SmtpPort' => 'Port SMTP',
	'General_AuthenticationMethodSmtp' => 'Mètode d\'autenticació SMTP',
	'General_SmtpUsername' => 'usuari SMTP',
	'General_SmtpPassword' => 'contrasenya SMTP',
	'General_SmtpEncryption' => 'encriptació SMTP',
	'General_InvalidResponse' => 'Les dades rebudes són invàlides.',
	'General_ChooseLanguage' => 'Tria idioma',
	'General_ChoosePeriod' => 'Triar període',
	'General_ChooseWebsite' => 'Triar lloc web',
	'General_Language' => 'Idioma',
	'General_PleaseUpdatePiwik' => 'Si us plau actualitzeu el Piwik',
	'General_UsePlusMinusIconsDocumentation' => 'Fes servir les icones de més i menys a l\'esquerra per navegar.',
	'General_Recommended' => '(recomanat)',
	'General_Goal' => 'Objectiu',
	'General_Outlink' => 'Enllaç extern',
	'General_Help' => 'Ajuda',
	'Actions_Actions' => 'Accions',
	'Actions_SubmenuPages' => 'Pàgines',
	'Actions_SubmenuOutlinks' => 'Enllaços externs',
	'Actions_SubmenuDownloads' => 'Descàrregues',
	'Actions_ColumnClicks' => 'Clics',
	'Actions_ColumnUniqueClicks' => 'Clics únics',
	'Actions_ColumnDownloads' => 'Descàrregues',
	'Actions_ColumnUniqueDownloads' => 'Descàrregues úniques',
	'Actions_ColumnPageName' => 'Nom de la pàgina',
	'Actions_ColumnClickedURL' => 'URL picada',
	'Actions_ColumnDownloadURL' => 'URL de descàrrega',
	'API_LoadedAPIs' => 'S\'ha carregat correctament un total de %s API',
	'CoreHome_CategoryNoData' => 'No hi ha dades en aquesta categoria. Proveu d\'<em>incloure tota la població</em>.',
	'CoreHome_ShowJSCode' => 'Mostra el codi JavaScript necessari',
	'CoreHome_PageOf_js' => '%1$s de %2$s',
	'CoreHome_PeriodDay' => 'Dia',
	'CoreHome_PeriodWeek' => 'Setmana',
	'CoreHome_PeriodMonth' => 'Mes',
	'CoreHome_PeriodYear' => 'Any',
	'CoreHome_PeriodDays' => 'dies',
	'CoreHome_PeriodWeeks' => 'setmanes',
	'CoreHome_PeriodMonths' => 'mesos',
	'CoreHome_PeriodYears' => 'anys',
	'CoreHome_DaySu_js' => 'dg',
	'CoreHome_DayMo_js' => 'dl',
	'CoreHome_DayTu_js' => 'dt',
	'CoreHome_DayWe_js' => 'dc',
	'CoreHome_DayTh_js' => 'dj',
	'CoreHome_DayFr_js' => 'dv',
	'CoreHome_DaySa_js' => 'ds',
	'CoreHome_MonthJanuary_js' => 'Gener',
	'CoreHome_MonthFebruary_js' => 'Febrer',
	'CoreHome_MonthMarch_js' => 'Març',
	'CoreHome_MonthApril_js' => 'Abril',
	'CoreHome_MonthMay_js' => 'Maig',
	'CoreHome_MonthJune_js' => 'Juny',
	'CoreHome_MonthJuly_js' => 'Juliol',
	'CoreHome_MonthAugust_js' => 'Agost',
	'CoreHome_MonthSeptember_js' => 'Setembre',
	'CoreHome_MonthOctober_js' => 'Octubre',
	'CoreHome_MonthNovember_js' => 'Novembre',
	'CoreHome_MonthDecember_js' => 'Desembre',
	'CorePluginsAdmin_Plugins' => 'Connectors',
	'CorePluginsAdmin_PluginsManagement' => 'Gestiona els connectors',
	'CorePluginsAdmin_MainDescription' => 'Els connectors augmenten la funcionalitat del Piwik. Un cop hi ha un connector instal·lat, podeu activar-lo i desactivar-lo aquí.',
	'CorePluginsAdmin_Plugin' => 'Connector',
	'CorePluginsAdmin_Version' => 'Versió',
	'CorePluginsAdmin_Status' => 'Estat',
	'CorePluginsAdmin_Action' => 'Acció',
	'CorePluginsAdmin_PluginHomepage' => 'Pàgina web',
	'CorePluginsAdmin_Activated' => 'Actiu',
	'CorePluginsAdmin_Active' => 'Actiu',
	'CorePluginsAdmin_Inactive' => 'Inactiu',
	'CorePluginsAdmin_Deactivate' => 'Desactiva',
	'CorePluginsAdmin_Activate' => 'Activa',
	'CorePluginsAdmin_MenuPlugins' => 'Connectors',
	'CoreUpdater_UpdateTitle' => 'Actualització del Piwik',
	'CoreUpdater_DatabaseUpgradeRequired' => 'És necessari actualitzar la base de dades',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'La base de dades del Piwik és antiga i cal actualitzar-la abans de continuar.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'La base de dades s\'actualitzarà de la versió %1$s a la nova %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Aquests connectors s\'actualitzaran: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'El procés d\'actualització pot durar una estona, tingueu paciència.',
	'CoreUpdater_UpgradePiwik' => 'Actualitza el Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Si sou un usuari avançat i trobeu un error en l\'actualització de la base de dades:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifiqueu i corregiu l\'origen de l\'error (per exemple: memory_limit o max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'executeu les consultes restants de l\'actualització que han fallat',
	'CoreUpdater_ErrorDIYHelp_3' => 'actualitzeu la taula `option` de la base de dades del Piwik, introduint la versió que ha fallat a l\'hora d\'actualitzar a version_core',
	'CoreUpdater_ErrorDIYHelp_4' => 'torneu a engegar l\'actualització (a través del navegador o la línia de comandes) per a continuar amb les actualitzacions restants.',
	'CoreUpdater_ErrorDIYHelp_5' => 'informeu sobre el problema (i la solució) per tal que puguem millorar el Piwik',
	'CoreUpdater_HelpMessageContent' => 'Comproveu les %1$s PMF del Piwik (en anglès) %2$s, que intenten explicar els errors més comuns a l\'actualització. %3$s Pregunteu a l\'administrador del sistema, podria ajudar-vos amb l\'error, que sembla estar relacionat amb el servidor o la instal·lació del MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Hi ha hagut un error crític durant el procés d\'actualització:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'El que hi ha a sobre és l\'error del nucli. Hauria d\'explicar la causa, però si necessiteu més ajuda, si us plau:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'La actualització s\'ha completat amb èxit, però hi ha hagut alguns problemes durant el procés. Si us plau, llegiu les descripcions que hi ha a sobre per a saber més detalls. Si voleu més informació:',
	'CoreUpdater_UpgradeComplete' => 'S\'ha actualitzat amb èxit!',
	'CoreUpdater_WarningMessages' => 'Avisos:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Hi ha hagut errors en l\'actualització dels connectors',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'S\'han desactivat automàticament els connectors següents: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'El Piwik s\'ha actualitzat amb èxit!',
	'CoreUpdater_ContinueToPiwik' => 'Vés cap al Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Actualitza automàticament',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Hi ha una nova versió del Piwik disponible.',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Podeu actualitzar a la versió %s automàticament o baixar-vos el paquet i instal·lar-lo manualment.',
	'CoreUpdater_DownloadX' => 'Descarrega %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'L\'actualització en un clic del Piwik ha estat cancel·lada. Si no podeu arreglar l\'error de més amunt, us recomanem que actualitzeu el Piwik manualment. %1$s Si us plau, mireu-vos la %2$sDocumentació d\'actualització (en anglès)%3$s per a començar!',
	'CoreUpdater_DownloadingUpdateFromX' => 'S\'està descarregant l\'actualització de %s',
	'CoreUpdater_UnpackingTheUpdate' => 'S\'està desempacant l\'actualització',
	'CoreUpdater_VerifyingUnpackedFiles' => 'S\'estan verificant els fitxers',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'S\'està creant una còpia de seguretat del fitxer de configuració a %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'S\'està instal·lant la darrera versió',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'El Piwik s\'ha actualitzat correctament!',
	'CoreUpdater_EmptyDatabaseError' => 'La base de dades %s està buida. Heu d\'editar o esborrar el fitxer de configuració del Piwik.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'El Piwik està actualitzat a la versió %s.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Arxiu incompatible: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Arxiu buit',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'L\'arxiu és incomplet: manquen alguns fitxers (per exemple, %s).',
	'Dashboard_Dashboard' => 'Tauler',
	'Dashboard_DeleteWidgetConfirm' => 'Realment voleu esborrar aquest giny?',
	'Dashboard_SelectWidget' => 'Escolliu el giny que voleu afegir a la consola',
	'Dashboard_AddPreviewedWidget_js' => 'Afegeix el giny al tauler',
	'Dashboard_WidgetPreview_js' => 'Previsualitza el giny',
	'Dashboard_Close_js' => 'Tanca',
	'Dashboard_TitleWidgetInDashboard_js' => 'Aquest giny ja es troba a la consola',
	'Dashboard_TitleClickToAdd_js' => 'Feu clic per a afegir-lo a la consola',
	'Dashboard_LoadingWidget_js' => 'S\'està carregant el giny…',
	'Dashboard_WidgetNotFound_js' => 'Aquest giny no s\'ha trobat',
	'DBStats_DatabaseUsage' => 'Ús de la base de dades',
	'DBStats_MainDescription' => 'El Piwik desa totes les anàlisis web la base de dades MySQL. Ara per ara, les taules del Piwik fan servir %s.',
	'DBStats_Table' => 'Taula',
	'DBStats_DataSize' => 'Grandària de les dades',
	'DBStats_IndexSize' => 'Grandària del l\'índex',
	'DBStats_TotalSize' => 'Grandària total',
	'Goals_ColumnConversions' => 'Conversions',
	'Goals_ColumnRevenue' => 'Ingressos',
	'Installation_Installation' => 'Instal·lació',
	'Installation_InstallationStatus' => 'Estat de la instal·lació',
	'Installation_PercentDone' => '%s%% fet',
	'Installation_NoConfigFound' => 'No s\'ha trobat el fitxer de configuració del Piwik i esteu intentant accedir una pàgina del Piwik.<br /><strong>  »Podeu <a href=\'index.php\'>instal·lar el Piwik ara</a></strong>.<br /><small>Si heu instal·lat el Piwik abans i teniu algunes taules a la vostra base de dades, no us amoïneu; podeu continuar fent servir les mateixes taules i les dades existents es conservaran!</small>',
	'Installation_DatabaseSetup' => 'Configuració de la base de dades',
	'Installation_DatabaseErrorConnect' => 'Hi ha hagut un error amb la connexió al servidor de bases de dades.',
	'Installation_JsTag' => 'Etiqueta JavaScript',
	'Installation_JsTagArchivingHelp' => 'Per a llocs amb un tràfic mitjà o alt, visiteu <a target="" href="http://piwik.org/docs/setup-auto-archiving/">Com configurar una pàgina d\'autoarxivació (en anglès)</a> per tal que el Piwik vagi realment ràpid!',
	'Installation_Congratulations' => 'Felicitats',
	'Installation_CongratulationsHelp' => '<p>Felicitats! La instal·lació del Piwik ha finalitzat.</p><p>Assegureu-vos que heu inserit el codi JavaScript a totes les pàgines, i espereu els vostres primers visitants!</p>',
	'Installation_ContinueToPiwik' => 'Vés cap al Piwik',
	'Installation_SetupWebsite' => 'Configura un lloc',
	'Installation_SetupWebsiteError' => 'Hi ha hagut un problema en el moment d\'afegir el lloc.',
	'Installation_SetupWebsiteSetupSuccess' => 'El lloc %s s\'ha creat amb èxit!',
	'Installation_SuperUserLogin' => 'Usuari administrador principal',
	'Installation_Password' => 'Contrasenya',
	'Installation_PasswordRepeat' => 'Torneu a escriure la contrasenya',
	'Installation_Email' => 'Correu-e',
	'Installation_SecurityNewsletter' => 'Envieu-me correus-e sobre les actualitzacions grans del Piwik i les alertes de seguretat',
	'Installation_CommunityNewsletter' => 'Envieu-me correus-e amb les actualitzacions de la comunitat (nous connectors, funcionalitats, etc.)',
	'Installation_PasswordDoNotMatch' => 'Les contrasenyes no coincideixen',
	'Installation_Requirements' => 'Requeriments del Piwik',
	'Installation_Optional' => 'Opcional',
	'Installation_Legend' => 'Llegenda',
	'Installation_Extension' => 'extensió',
	'Installation_SystemCheck' => 'Comprovació del sistema',
	'Installation_SystemCheckPhp' => 'Versió del PHP',
	'Installation_SystemCheckExtensions' => 'Altres extensions necessàries',
	'Installation_SystemCheckDatabaseHelp' => 'El Piwik necessita l\'extensió mysqli o ambdues extensións PDO i pdo_mysql.',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'En un servidor Linux podeu compilar el php amb les següents opcions: %1$s Al fitxer php.ini, afegiu les línies: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Trobareu més informació a <a style="color:red" href="http://php.net/pdo">PHP PDO</a> i <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'En un servidor Windows podeu afegir les línies següents al fitxer php.ini: %s',
	'Installation_SystemCheckSplHelp' => 'Heu de configurar i recompilar el PHP amb la biblioteca Standard PHP Library (SPL) activada (per defecte).',
	'Installation_SystemCheckZlibHelp' => 'Heu de configurar i recompilar el PHP amb el suport per a "zlib" habilitat, --with-zlib.',
	'Installation_SystemCheckWriteDirs' => 'Directoris amb permisos d\'escriptura',
	'Installation_SystemCheckWriteDirsHelp' => 'Per a arreglar aquest error al vostre sistema Linux, proveu d\'entrar les ordres següents',
	'Installation_SystemCheckMemoryLimit' => 'Límit de memòria',
	'Installation_SystemCheckMemoryLimitHelp' => 'En un lloc web amb trànsit elevat, la creació de l\'arxiu pot necessitar més memòria de l\'acceptada actualment.<br />Feu una ullada al \'memory_limit\' del vostre fitxer php.ini si és necessari.',
	'Installation_SystemCheckOpenURL' => 'Obre l\'adreça',
	'Installation_SystemCheckOpenURLHelp' => 'Les subscripcions a les llistes de correu, notificacions d\'actualització i actualitzacions en un clic necessiten l\'extensió "curl", allow_url_fopen=On, o fsockopen() actiu.',
	'Installation_SystemCheckGD' => 'GD > 2.x (gràfics)',
	'Installation_SystemCheckGDHelp' => 'Els gràfics petits no funcionaran.',
	'Installation_SystemCheckFunctions' => 'Funcions necessàries',
	'Installation_SystemCheckTimeLimitHelp' => 'En un lloc web amb trànsit elevat, la creació de l\'arxiu pot necessitar més temps de l\'acceptada actualment.<br />Feu una ullada al \'max_execution_time\' del vostre fitxer php.ini si és necessari.',
	'Installation_SystemCheckMailHelp' => 'Les opinions i els missatges de pèrdua de la contrassenya no s\'enviaran sense la funció mail().',
	'Installation_SystemCheckError' => 'Hi ha hagut un error i s\'ha d\'arreglar abans de que pugueu continuar.',
	'Installation_SystemCheckWarning' => 'El Piwik funcionarà amb normalitat, però algunes funcions potser no estaran disponibles',
	'Installation_Tables' => 'S\'estan creant les taules…',
	'Installation_TablesWithSameNamesFound' => 'Algunes %1$s taules de la base de dades %2$s tenen el mateix nom que les taules que el Piwik intenta crear',
	'Installation_TablesFound' => 'Aquestes taules s\'han trobat a la base de dades:',
	'Installation_TablesWarningHelp' => 'Podeu escollir entre fer servir les taules existents de la base de dades o fer una instal·lació neta per a esborrar les dades existents a la base de dades.',
	'Installation_TablesReuse' => 'Fes servir les taules existents',
	'Installation_TablesDelete' => 'Esborra les taules existents',
	'Installation_TablesDeletedSuccess' => 'Les taules del Piwik existents s\'han esborrat amb èxit.',
	'Installation_TablesCreatedSuccess' => 'Les taules s\'han creat amb èxit!',
	'Installation_DatabaseCreatedSuccess' => 'La base de dades %s s\'ha creat correctament!',
	'Installation_GoBackAndDefinePrefix' => 'Torna enrere i defineix un prefix per a les taules',
	'Installation_ConfirmDeleteExistingTables' => 'Realment voleu esborrar les taules %s de la base de dades? AVÍS: NO ES PODRAN RECUPERAR LES DADES!',
	'Installation_Welcome' => 'Benvingut/da!',
	'Installation_WelcomeHelp' => '<p>El Piwik és un programari d\'anàlisi web de codi obert que facilita la presa d\'informació dels vostres visitants.</p><p>Aquest procés està dividit en %s passos fàcils i trigarà uns 5 minuts.</p>',
	'Installation_ErrorInvalidState' => 'Hi ha hagut un error: sembla que  esteu intentant saltar-vos un pas de la instal·lació, o teniu les galetes desactivades o el fitxer de configuració del Piwik ja existeix. %1$sAssegureu-vos que teniu les galetes activades%2$s i torneu enrera %3$s al primer pas de la instal·lació %4$s.',
	'Login_PluginDescription' => 'Pàgina d\'inici de sessió, dóna les credencials als usuaris',
	'Login_LoginPasswordNotCorrect' => 'L\'usuari o la contrasenya no són correctes',
	'Login_Password' => 'Contrasenya',
	'Login_PasswordRepeat' => 'Contrasenya (torneu-la a escriure)',
	'Login_ChangePassword' => 'Canvia la contrasenya',
	'Login_LoginOrEmail' => 'Nom d\'usuari o correu-e',
	'Login_LogIn' => 'Inicia la sessió',
	'Login_Logout' => 'Surt',
	'Login_LostYourPassword' => 'Heu perdut la contrasenya?',
	'Login_RemindPassword' => 'Recorda la contrasenya',
	'Login_PasswordResetToken' => 'Codi de reinicialització de la contrasenya.',
	'Login_PasswordReminder' => 'Si us plau, inseriu el vostre nom d\'usuari o el vostre correu-e. Rebreu una contrasenya nova al vostre correu-e.',
	'Login_PasswordsDoNotMatch' => 'Les contrasenyes no coincideixen',
	'Login_PasswordSuccessfullyChanged' => 'La contrasenya ha estat canviada amb èxit!',
	'Login_InvalidUsernameEmail' => 'Aquest usuari i/o direcció de correu-e és invàlid.',
	'Login_InvalidOrExpiredToken' => 'El codi és invàlid o ha caducat',
	'Login_MailTopicPasswordRecovery' => 'Recuperació de la contrasenya',
	'Login_MailPasswordRecoveryBody' => 'Hola %1$s, una petició de reinicialització de la contrasenya ha estat rebuda de %2$s. Per a reiniciar-la: 1)Aneu al formulari de reinicialització de contrasenyes a %3$s 2)Introduïu el següent codi: %4$s 3)Ompliu el formulari (introduint la nova contrasenya dos cops) i envieu-lo. Nota: el codi caduca en 24 hores.',
	'Login_PasswordSent' => 'La informació per a canviar la contrasenya s\'ha enviat. Reviseu el vostre correu-e',
	'Login_ContactAdmin' => 'Possiblement sigui perquè el vostre proveïdor d\'allotjament ha desactivat la funció mail().<br />Contacteu amb l\'administrador del lloc.',
	'Provider_WidgetProviders' => 'Proveïdors',
	'Provider_ColumnProvider' => 'Proveïdor',
	'Provider_SubmenuLocationsProvider' => 'Localitzacions i proveïdors',
	'Referers_Referers' => 'Referents',
	'Referers_SearchEngines' => 'Cercadors',
	'Referers_Keywords' => 'Paraules clau',
	'Referers_DirectEntry' => 'Registre directe',
	'Referers_Websites' => 'Llocs web',
	'Referers_Campaigns' => 'Campanyes',
	'Referers_Evolution' => 'Evolució durant el període',
	'Referers_Type' => 'Tipus de referent',
	'Referers_ColumnRefererType' => 'Tipus de referent',
	'Referers_ColumnSearchEngine' => 'Cercador',
	'Referers_ColumnWebsite' => 'Lloc web',
	'Referers_ColumnWebsitePage' => 'Pàgina web',
	'Referers_ColumnKeyword' => 'Paraula clau',
	'Referers_ColumnCampaign' => 'Campanya',
	'Referers_DetailsByRefererType' => 'Detalls segons el tipus de referent',
	'Referers_TypeDirectEntries' => 'Hi ha %s entrades directes',
	'Referers_TypeSearchEngines' => 'Hi ha %s visites provinents dels motors de cerca',
	'Referers_TypeWebsites' => 'Hi ha %s visites provinents d\'altres llocs',
	'Referers_TypeCampaigns' => 'Hi ha %s visites provinents de campanyes',
	'Referers_Distinct' => 'Referents diferents segons el tipus',
	'Referers_DistinctSearchEngines' => 'cercadors diferents',
	'Referers_DistinctKeywords' => 'paraules clau diferents',
	'Referers_DistinctCampaigns' => 'campanyes diferents',
	'Referers_DistinctWebsites' => 'llocs web diferents',
	'Referers_SubmenuSearchEngines' => 'Cercadors i paraules clau',
	'Referers_SubmenuWebsites' => 'Llocs web',
	'Referers_SubmenuCampaigns' => 'Campanyes',
	'Referers_WidgetKeywords' => 'Llistat de paraules clau',
	'Referers_WidgetCampaigns' => 'Llistat de campanyes',
	'Referers_WidgetExternalWebsites' => 'Llistat de llocs web externs',
	'Referers_WidgetSearchEngines' => 'Millors motors de cerca',
	'Referers_WidgetOverview' => 'Resum',
	'SitesManager_Sites' => 'Llocs',
	'SitesManager_WebsitesManagement' => 'Gestiona els llocs',
	'SitesManager_MainDescription' => 'Els informes d\'anàlisi web necessiten llocs web! Afegiu, actualitzeu i esborreu-ne. Veieu també el codi JavaScript que heu d\'inserir a les pàgines.',
	'SitesManager_JsTrackingTag' => 'Etiqueta de seguiment JavaScript',
	'SitesManager_JsTrackingTagHelp' => 'Aquí teniu l\'etiqueta de seguiment JavaScript per tal d\'incloure-la a totes les pàgines',
	'SitesManager_ShowTrackingTag' => 'mostra l\'etiqueta de seguiment',
	'SitesManager_NoWebsites' => 'No teniu cap lloc que pugueu administrar',
	'SitesManager_AddSite' => 'Afegeix un lloc nou',
	'SitesManager_Urls' => 'Adreces',
	'SitesManager_MenuSites' => 'Llocs',
	'SitesManager_DeleteConfirm_js' => 'Realment voleu esborrar el lloc \'%s\'?',
	'SitesManager_ExceptionDeleteSite' => 'No és possible eliminar aquest lloc ja que és l\'únic configurat. Afegiu un altre lloc primer i, llavors, ja esborrareu aquest.',
	'SitesManager_ExceptionNoUrl' => 'Heu d\'especificar una URL com a mínim.',
	'SitesManager_ExceptionEmptyName' => 'El nom del lloc no pot estar buit.',
	'SitesManager_ExceptionInvalidUrl' => 'L\'adreça \'%s\' no és vàlida.',
	'TranslationsAdmin_MenuTranslations' => 'Traduccions',
	'TranslationsAdmin_MenuLanguages' => 'Idiomes',
	'TranslationsAdmin_LanguageCode' => 'Codi de l\'idioma',
	'TranslationsAdmin_Plugin' => 'Connector',
	'TranslationsAdmin_Definition' => 'Definició',
	'TranslationsAdmin_DefaultString' => 'Original (anglès)',
	'TranslationsAdmin_TranslationString' => 'Traducció (idioma actual: %s)',
	'TranslationsAdmin_Translations' => 'Traduccions',
	'TranslationsAdmin_FixPermissions' => 'Si us plau, configureu bé els permisos dels fitxers',
	'TranslationsAdmin_AddLanguage' => 'Afegeix un idioma',
	'TranslationsAdmin_Export' => 'Exporta un idioma',
	'TranslationsAdmin_Import' => 'Importa un idioma',
	'UserCountry_Country' => 'País',
	'UserCountry_Continent' => 'Continent',
	'UserCountry_DistinctCountries' => 'Hi ha %s països diferents',
	'UserCountry_SubmenuLocations' => 'Localització',
	'UserCountry_WidgetContinents' => 'Continents',
	'UserCountry_WidgetCountries' => 'Països',
	'UserCountry_country_ac' => 'Illes Ascensió',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Emirats Àrabs Units',
	'UserCountry_country_af' => 'Afganistan',
	'UserCountry_country_ag' => 'Antigua i Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albània',
	'UserCountry_country_am' => 'Armènia',
	'UserCountry_country_an' => 'Antilles Neerlandeses',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antàrtida',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Samoa Nord-americana',
	'UserCountry_country_at' => 'Àustria',
	'UserCountry_country_au' => 'Austràlia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Illes Åland',
	'UserCountry_country_az' => 'Azerbaidjan',
	'UserCountry_country_ba' => 'Bòsnia i Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangla Desh',
	'UserCountry_country_be' => 'Bèlgica',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgària',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthélemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Brunei',
	'UserCountry_country_bo' => 'Bolívia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bs' => 'Bahames',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Birmània (Myanmar)',
	'UserCountry_country_bv' => 'Bouvet',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Bielorússia',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canadà',
	'UserCountry_country_cc' => 'Illes Cocos',
	'UserCountry_country_cd' => 'República Democràtica del Congo',
	'UserCountry_country_cf' => 'República Centreafricana',
	'UserCountry_country_cg' => 'República del Congo',
	'UserCountry_country_ch' => 'Suïssa',
	'UserCountry_country_ci' => 'Costa d\'Ivori',
	'UserCountry_country_ck' => 'Illes Cook',
	'UserCountry_country_cl' => 'Xile',
	'UserCountry_country_cm' => 'Camerun',
	'UserCountry_country_cn' => 'Xina',
	'UserCountry_country_co' => 'Colòmbia',
	'UserCountry_country_cp' => 'Illa Clipperton',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Sèrbia i Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cap Verd',
	'UserCountry_country_cx' => 'Illa Christmas',
	'UserCountry_country_cy' => 'Xipre',
	'UserCountry_country_cz' => 'República Txeca',
	'UserCountry_country_de' => 'Alemanya',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Dinamarca',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'República Dominicana',
	'UserCountry_country_dz' => 'Algèria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Equador',
	'UserCountry_country_ee' => 'Estònia',
	'UserCountry_country_eg' => 'Egipte',
	'UserCountry_country_eh' => 'Sàhara Occidental',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Espanya',
	'UserCountry_country_et' => 'Etiòpia',
	'UserCountry_country_eu' => 'Unió Europea',
	'UserCountry_country_fi' => 'Finlàndia',
	'UserCountry_country_fj' => 'Illes Fiji',
	'UserCountry_country_fk' => 'Illes Malvines',
	'UserCountry_country_fm' => 'Estats Federats de Micronèsia',
	'UserCountry_country_fo' => 'Illes Fèroe',
	'UserCountry_country_fr' => 'França',
	'UserCountry_country_fx' => 'França, Metropolitana',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Gran Bretanya',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Geòrgia',
	'UserCountry_country_gf' => 'Guaiana Francesa',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Grenlàndia',
	'UserCountry_country_gm' => 'Gàmbia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Illa Guadalupe',
	'UserCountry_country_gq' => 'Guinea Ecuatorial',
	'UserCountry_country_gr' => 'Grècia',
	'UserCountry_country_gs' => 'Illes Geòrgia del Sud i Sandwich del Sud',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Illes Heard i McDonald',
	'UserCountry_country_hn' => 'Hondures',
	'UserCountry_country_hr' => 'Croàcia',
	'UserCountry_country_ht' => 'Haití',
	'UserCountry_country_hu' => 'Hongria',
	'UserCountry_country_ic' => 'Illes Canàries',
	'UserCountry_country_id' => 'Indonèsia',
	'UserCountry_country_ie' => 'Irlanda',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man (illa)',
	'UserCountry_country_in' => 'Índia',
	'UserCountry_country_io' => 'Territori Britànic de l\'Oceà Índic',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Islàndia',
	'UserCountry_country_it' => 'Itàlia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordània',
	'UserCountry_country_jp' => 'Japó',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kirguizistan',
	'UserCountry_country_kh' => 'Cambodja',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comores',
	'UserCountry_country_kn' => 'Saint Kitts i Nevis',
	'UserCountry_country_kp' => 'Korea del Nord',
	'UserCountry_country_kr' => 'Corea del Sud',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Illes Caiman',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Líban',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Libèria',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lituània',
	'UserCountry_country_lu' => 'Luxemburg',
	'UserCountry_country_lv' => 'Letònia',
	'UserCountry_country_ly' => 'Líbia',
	'UserCountry_country_ma' => 'Marroc',
	'UserCountry_country_mc' => 'Mònaco',
	'UserCountry_country_md' => 'Moldàvia',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Illa de Sant Martí',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Illes Marshall',
	'UserCountry_country_mk' => 'Macedònia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongòlia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Illes Marianes Septentrionals',
	'UserCountry_country_mq' => 'Martinica',
	'UserCountry_country_mr' => 'Mauritània',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Maurici',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mèxic',
	'UserCountry_country_my' => 'Malàisia',
	'UserCountry_country_mz' => 'Moçambic',
	'UserCountry_country_na' => 'Namíbia',
	'UserCountry_country_nc' => 'Nova Caledònia',
	'UserCountry_country_ne' => 'Níger',
	'UserCountry_country_nf' => 'Illa Norfolk',
	'UserCountry_country_ng' => 'Nigèria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Països Baixos',
	'UserCountry_country_no' => 'Noruega',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Zona neutra',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nova Zelanda',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panamà',
	'UserCountry_country_pe' => 'Perú',
	'UserCountry_country_pf' => 'Polinèsia Francesa',
	'UserCountry_country_pg' => 'Papua Nova Guinea',
	'UserCountry_country_ph' => 'Filipines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polònia',
	'UserCountry_country_pm' => 'Saint-Pierre i Miquelon',
	'UserCountry_country_pn' => 'Illes Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Territori Palestí',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguai',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Illa de la Reunió',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Sèrbia',
	'UserCountry_country_ru' => 'Rússia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Aràbia Saudita',
	'UserCountry_country_sb' => 'Illes Salomó',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Suècia',
	'UserCountry_country_sf' => 'Finlàndia',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Eslovènia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Eslovàquia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somàlia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'São Tomé i Príncipe',
	'UserCountry_country_su' => 'Antiga URSS',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Síria',
	'UserCountry_country_sz' => 'Swazilàndia',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Illes Turks i Caicos',
	'UserCountry_country_td' => 'Txad',
	'UserCountry_country_tf' => 'Terres Australs i Antàrtiques Franceses',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Tailàndia',
	'UserCountry_country_tj' => 'Tadjikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Timor Oriental',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunísia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Timor Oriental',
	'UserCountry_country_tr' => 'Turquia',
	'UserCountry_country_tt' => 'Trinitat i Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzània',
	'UserCountry_country_ua' => 'Ucraïna',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Regne Unit',
	'UserCountry_country_um' => 'Illes Perifèriques Menors dels EUA',
	'UserCountry_country_us' => 'EUA',
	'UserCountry_country_uy' => 'Uruguai',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Ciutat del Vaticà',
	'UserCountry_country_vc' => 'Saint Vincent i les Grenadines',
	'UserCountry_country_ve' => 'Veneçuela',
	'UserCountry_country_vg' => 'Illes Verges Britàniques',
	'UserCountry_country_vi' => 'Illes Verges Americanes',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis i Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Iemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Iugoslàvia',
	'UserCountry_country_za' => 'Sud-àfrica',
	'UserCountry_country_zm' => 'Zàmbia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Àfrica',
	'UserCountry_continent_asi' => 'Àsia',
	'UserCountry_continent_amn' => 'Amèrica del Nord',
	'UserCountry_continent_ams' => 'Amèrica Central i del Sud',
	'UserCountry_continent_oce' => 'Oceania',
	'UserSettings_VisitorSettings' => 'Configuració del visitant',
	'UserSettings_BrowserFamilies' => 'Motors dels navegadors',
	'UserSettings_Browsers' => 'Navegadors',
	'UserSettings_Plugins' => 'Connectors',
	'UserSettings_Configurations' => 'Configuracions',
	'UserSettings_OperatingSystems' => 'Sistemes operatius',
	'UserSettings_Resolutions' => 'Resolucions',
	'UserSettings_WideScreen' => 'Pantalla panoràmica',
	'UserSettings_ColumnBrowserFamily' => 'Família del navegador',
	'UserSettings_ColumnBrowser' => 'Navegador',
	'UserSettings_ColumnPlugin' => 'Connector',
	'UserSettings_ColumnConfiguration' => 'Configuració',
	'UserSettings_ColumnOperatingSystem' => 'Sistema operatiu',
	'UserSettings_ColumnResolution' => 'Resolució',
	'UserSettings_ColumnTypeOfScreen' => 'Tipus de pantalla',
	'UserSettings_WidgetResolutions' => 'Resoulucions',
	'UserSettings_WidgetBrowsers' => 'Navegadors',
	'UserSettings_WidgetPlugins' => 'Llistat de connectors',
	'UserSettings_WidgetWidescreen' => 'Normal / panoràmica',
	'UserSettings_WidgetBrowserFamilies' => 'Navegadors per motor',
	'UserSettings_WidgetOperatingSystems' => 'Sistemes operatius',
	'UserSettings_WidgetGlobalVisitors' => 'Configuracions globals dels visitants',
	'UserSettings_SubmenuSettings' => 'Configuracions',
	'UsersManager_UsersManagement' => 'Gestiona els usuaris',
	'UsersManager_UsersManagementMainDescription' => 'Creeu nous usuaris o actualitzeu els existents.    Podeu configurar els seus permisos a dalt.',
	'UsersManager_ManageAccess' => 'Gestiona els permisos',
	'UsersManager_MainDescription' => 'Decidiu quin tipus d\'accés té cada usuari al Piwik. També podeu configurar tots els llocs web de cop.',
	'UsersManager_Sites' => 'Llocs',
	'UsersManager_AllWebsites' => 'Tots els llocs',
	'UsersManager_ApplyToAllWebsites' => 'Aplica a tots els llocs',
	'UsersManager_User' => 'Usuari',
	'UsersManager_PrivNone' => 'Sense accés',
	'UsersManager_PrivView' => 'Vista',
	'UsersManager_PrivAdmin' => 'Administració',
	'UsersManager_ChangeAllConfirm' => 'Realment voleu canviar els permisos de \'%s\' a tots els llocs web?',
	'UsersManager_Password' => 'Contrasenya',
	'UsersManager_Email' => 'Correu-e',
	'UsersManager_Alias' => 'Àlies',
	'UsersManager_Edit' => 'Edita',
	'UsersManager_AddUser' => 'Afegeix un usuari nou',
	'UsersManager_MenuUsers' => 'Usuaris',
	'UsersManager_DeleteConfirm_js' => 'Esteu segur que voleu eliminar l\'usuari %s?',
	'UsersManager_ExceptionLoginExists' => 'L\'usuari \'%s\' ja existeix.',
	'UsersManager_ExceptionEmailExists' => 'La direcció de correu-e \'%s\' ja està en un altre compte.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'El nom d\'usuari ha de tenir una longitud d\'entre %1$s i %2$s caràcters i estar format únicament per lletres, xifres o els caràcters \'_\', \'-\' o \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'La direcció de correu-e no té un format vàlid.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'L\'usuari \'%s\' no existeix i, per tant, no es pot esborrar.',
	'UsersManager_ExceptionAdminAnonymous' => 'No podeu donar permisos d\'administració a l\'usuari \'anonymous\' (anònim).',
	'UsersManager_ExceptionEditAnonymous' => 'L\'usuari anònim no es pot editar o esborrar. El Piwik el fa servir per als usuaris que no han iniciat encara la sessió. Per exemple, podeu fer públiques les vostres estadístiques garantint el permís \'vista\' a l\'usuari \'anonymous\' (anònim).',
	'UsersManager_ExceptionSuperUser' => 'Aquest és el superusuari i no es pot consultar, editar o esborrar mitjançant l\'API. Podeu editar-lo manualment en el fitxer de configuració del Piwik.',
	'UsersManager_ExceptionUserDoesNotExist' => 'L\'usuari \'%s\' no existeix.',
	'UsersManager_ExceptionAccessValues' => 'El paràmetre permisos ha de tenir un dels següents valors: [ %s ]',
	'VisitFrequency_Evolution' => 'Evolució del període',
	'VisitFrequency_ColumnReturningVisits' => 'Visitants que retornen (antics)',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Accions dels visitants antics',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Raó de rebots',
	'VisitFrequency_ReturnVisits' => 'Han tornat %s visitants',
	'VisitFrequency_ReturnActions' => 'Els visitants que han tornat han fet %s accions',
	'VisitFrequency_ReturnBounceRate' => '%s visitants antics han rebotat (abandonat el lloc després de veure una pàgina)',
	'VisitFrequency_WidgetOverview' => 'Resum de la freqüència',
	'VisitFrequency_WidgetGraphReturning' => 'Gràfic de les visites que han tornat',
	'VisitFrequency_SubmenuFrequency' => 'Freqüència',
	'VisitorInterest_VisitsPerDuration' => 'Visites segons la durada',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visites segons el nombre de pàgines',
	'VisitorInterest_ColumnVisitDuration' => 'Durada de la visita',
	'VisitorInterest_ColumnPagesPerVisit' => 'Pàgines per visita',
	'VisitorInterest_WidgetLengths' => 'Durada de les visites',
	'VisitorInterest_WidgetPages' => 'Pàgines per visita',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_OnePage' => '1 pàgina',
	'VisitorInterest_NPages' => '%s pàgines',
	'VisitsSummary_VisitsSummary' => 'Resum de les visites',
	'VisitsSummary_NbVisits' => '%s visites',
	'VisitsSummary_NbUniqueVisitors' => '%s visitants únics',
	'VisitsSummary_MaxNbActions' => 'Hi ha %s accions màximes en una visita',
	'VisitsSummary_NbVisitsBounced' => '%s visites han rebotat (abandonat el lloc després de veure una pàgina)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolució dels darrers %s',
	'VisitsSummary_GenerateTime' => 'S\'han trigat %s segons en generar la pàgina',
	'VisitsSummary_GenerateQueries' => 'S\'ha executat un total de %s consultes',
	'VisitsSummary_WidgetLastVisits' => 'Gràfic de les darreres visites',
	'VisitsSummary_WidgetVisits' => 'Resum de les visites',
	'VisitsSummary_WidgetLastVisitors' => 'Gràfic dels darrers visitants únics',
	'VisitsSummary_WidgetOverviewGraph' => 'Resum amb gràfic',
	'VisitsSummary_SubmenuOverview' => 'Resum',
	'VisitTime_LocalTime' => 'Visites segons l\'hora local',
	'VisitTime_ServerTime' => 'Visites segons l\'hora del servidor',
	'VisitTime_ColumnServerTime' => 'Hora del servidor',
	'VisitTime_ColumnLocalTime' => 'Hora local',
	'VisitTime_WidgetLocalTime' => 'Visites segons l\'hora local',
	'VisitTime_WidgetServerTime' => 'Visites segons l\'hora del servidor',
	'VisitTime_SubmenuTimes' => 'Hores',
	'VisitTime_NHour' => '%sh',
);
